#!/bin/sh
#
# $Copyright: Copyright (c) 2021 Veritas Technologies LLC.
# All rights reserved.
#
# THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION AND TRADE SECRETS OF
# VERITAS TECHNOLOGIES LLC.  USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED
# WITHOUT THE PRIOR EXPRESS WRITTEN PERMISSION OF VERITAS TECHNOLOGIES LLC.
#
# The  Licensed  Software  and  Documentation  are  deemed  to be commercial
# computer  software  as  defined  in  FAR  12.212 and subject to restricted
# rights  as  defined in FAR Section 52.227-19 "Commercial Computer Software
# - Restricted  Rights"  and  DFARS 227.7202,  et seq.  "Commercial Computer
# Software  and  Commercial Computer Software Documentation," as applicable,
# and any successor regulations, whether delivered by Veritas as on premises
# or  hosted  services.  Any  use,  modification,  reproduction  release,
# performance,  display  or  disclosure  of  the  Licensed  Software  and
# Documentation by the U.S. Government shall be solely in accordance with
# the terms of this Agreement. $
# $Revision: 1.4.5.37 $
# $Source: /project/arrayrep/src/srdf/unix/addSRDFType.sh,v $
#

add_fun(){
result="`$@ 2>&1`"
if [ $? -eq 1 ]; then
	if [ `echo "$result" | grep -c "already exist"` -eq 1 -o `echo "$result" | grep -c "already in"` -eq 1 ]; then
		:	
	else
		echo "$@";
	fi
fi
}
		
VCSHOME="${VCS_HOME:-/opt/VRTSvcs}"
HACLUS="$VCSHOME/bin/haclus"
HACONF="$VCSHOME/bin/haconf"
HATYPE="$VCSHOME/bin/hatype"
HAATTR="$VCSHOME/bin/haattr"
HARES="$VCSHOME/bin/hares"

ro=`$HACLUS -value ReadOnly`
if [ $? -eq 0 ]; then
	if [ "$ro" -eq 1 ];
	then
		$HACONF -makerw
	fi
else 
	echo "Unable to add the SRDF and SRDFSnap types, VCS is not running. Start VCS and execute the script /etc/VRTSvcs/conf/sample_srdf/addSRDFType.sh "
	exit 0;
fi

add_fun "$HATYPE -add SRDF"
$HATYPE -modify SRDF SourceFile "./SRDFTypes.cf"
$HATYPE -modify SRDF ArgList SymHome GrpName DevFOTime AutoTakeover SplitTakeover Mode IsCompositeGroup SwapRoles DetailedMonitoring SymapiServers ComputeDRSLA LinkMonitor ConfValidate AdvancedOpts SymcliDbFile
$HATYPE -modify SRDF ActionTimeout 180
$HATYPE -modify SRDF OfflineMonitorInterval 0 
$HATYPE -modify SRDF MonitorInterval 300
$HATYPE -modify SRDF OpenTimeout 180
$HATYPE -modify SRDF RestartLimit 1

if [ `uname` = "AIX" ]
then
    $HATYPE -modify SRDF SupportedActions update ld2pd PreSwitch vxvm_scan ReportRPOData StartWriter GetCurrentRPO StartRPOComputation StopRPOComputation dev_scan validate_config
else
    $HATYPE -modify SRDF SupportedActions update ld2pd PreSwitch ReportRPOData StartWriter GetCurrentRPO StartRPOComputation StopRPOComputation dev_scan validate_config
fi

$HATYPE -modify SRDF NameRule "resource.GrpName" >/dev/null 2>&1
add_fun "$HAATTR -add SRDF SymHome -string "/usr/symcli""
add_fun "$HAATTR -add SRDF GrpName -string"
add_fun "$HAATTR -add SRDF DevFOTime -integer 2"
add_fun "$HAATTR -add SRDF AutoTakeover -boolean 0"
add_fun "$HAATTR -add SRDF SplitTakeover -boolean 0"
add_fun "$HAATTR -add SRDF LinkMonitor -integer 0"
add_fun "$HAATTR -add SRDF ConfValidate -integer 0"
add_fun "$HAATTR -add SRDF Mode -string"
add_fun "$HAATTR -add SRDF IsCompositeGroup -boolean 0"
add_fun "$HAATTR -add SRDF SwapRoles -integer 1"
add_fun "$HAATTR -add SRDF DetailedMonitoring -integer 0"
add_fun "$HAATTR -add SRDF SymapiServers -string -vector"
add_fun "$HAATTR -add SRDF ComputeDRSLA -integer 0"
add_fun "$HAATTR -add -temp SRDF VCSResLock -string"
add_fun "$HAATTR -add -temp SRDF Tagging -boolean"
add_fun "$HAATTR -add -temp SRDF Counter -integer 0"
add_fun "$HAATTR -add -temp SRDF PrevState  -string "normal""
add_fun "$HAATTR -add -static SRDF RegList -keylist"
add_fun "$HATYPE -modify SRDF RegList ComputeDRSLA"
add_fun "$HAATTR -add SRDF AdvancedOpts -string -assoc ExtendMonitor null"
add_fun "$HAATTR -add SRDF SymcliDbFile -string"

srdfsnap=`$HATYPE -list | grep SRDFSnap`
add_fun "$HATYPE -add SRDFSnap"
$HATYPE -modify SRDFSnap SourceFile "./SRDFTypes.cf"
add_fun "$HAATTR -add SRDFSnap CopyMode -string"
add_fun "$HAATTR -default SRDFSnap CopyMode mirror"
# If SRDFSnap is not installed we dont enter inside the if block 
# In the if block we check the value of IsSpaceOptimizedSnapshot for every SRDFSnap resource 
# and set the value of CopyMode attribute. If IsSpaceOptimizedSnapshot was one then set the
# the value of CopyMode to snap otherwise mirror
update=0
if [ ! -z "$srdfsnap" ] && [ $srdfsnap = "SRDFSnap" ]
then 
	spaceOS=`$HATYPE -display SRDFSnap | grep IsSpaceOptimizedSnapshot`
	if [ ! -z "$spaceOS" ]
	then
        $HATYPE -modify SRDFSnap ArgList TargetResName MountSnapshot UseSnapshot RequireSnapshot SavePoolName DiskGroupSnapList CopyMode UseTgt
        update=1;
    fi
    srdfsnap_res=`$HARES -list Type=SRDFSnap | awk '{print \$1}'`
    if [ ! -z "$srdfsnap_res" ]
    then
        res_arr=`echo $srdfsnap_res | tr -s '\n' ' '`
        index=0
        for resource in $res_arr
        do
            old_space=`$HARES -value $resource IsSpaceOptimizedSnapshot 2>/dev/null`
            if [ "$?" != "0" ]; then
                break;
            fi
            if [ "$old_space" = "1" ]
            then
                $HARES -modify $resource CopyMode snap
            else
                $HARES -modify $resource CopyMode mirror
            fi
            index=`expr $index + 1`
        done
    fi
    $HAATTR -delete SRDFSnap IsSpaceOptimizedSnapshot 2>/dev/null
    update=1
    $HACONF -dump
fi
if [ "$update" = 0 ]
then
    $HATYPE -modify SRDFSnap ArgList TargetResName MountSnapshot UseSnapshot RequireSnapshot SavePoolName DiskGroupSnapList CopyMode UseTgt
fi
$HATYPE -modify SRDFSnap OpenTimeout 180
add_fun "$HAATTR -add SRDFSnap TargetResName -string"
add_fun "$HAATTR -add SRDFSnap MountSnapshot -boolean"
add_fun "$HAATTR -default SRDFSnap MountSnapshot 1"
add_fun "$HAATTR -add SRDFSnap UseSnapshot -boolean"
add_fun "$HAATTR -default SRDFSnap UseSnapshot 1"
add_fun "$HAATTR -add SRDFSnap RequireSnapshot -boolean"
add_fun "$HAATTR -default SRDFSnap RequireSnapshot 1"
add_fun "$HAATTR -add SRDFSnap SavePoolName -string"
add_fun "$HAATTR -add SRDFSnap DiskGroupSnapList -string"
add_fun "$HAATTR -add SRDFSnap UseTgt -boolean"
add_fun "$HAATTR -default SRDFSnap UseTgt 0"
add_fun "$HAATTR -add -temp SRDFSnap Responsibility -string"
add_fun "$HAATTR -add -temp SRDFSnap FDFile -string"
add_fun "$HAATTR -add -temp SRDFSnap VCSResLock -string"
add_fun "$HAATTR -add -static SRDFSnap RegList -keylist"
add_fun "$HATYPE -modify SRDFSnap RegList -add MountSnapshot"
add_fun "$HATYPE -modify SRDFSnap RegList -add UseSnapshot"
add_fun "$HATYPE -modify SRDFSnap RegList -add SavePoolName"
add_fun "$HATYPE -modify SRDFSnap RegList -add CopyMode"
add_fun "$HATYPE -modify SRDFSnap RegList -add DiskGroupSnapList"

if [ "$ro" -eq 1 ];
then
	$HACONF -dump -makero
else
	$HACONF -dump
fi

